==> haskell-byteorder-1.0.4-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteorder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byteorder
version:              1.0.4
visibility:           public
id:                   byteorder-1.0.4-KgJ9EHrGIhpJCFFHbRpXHY
key:                  byteorder-1.0.4-KgJ9EHrGIhpJCFFHbRpXHY
license:              BSD-3-Clause
maintainer:           Antoine Latter <aslatter@gmail.com>
author:               Antoine Latter
homepage:             http://community.haskell.org/~aslatter/code/byteorder
synopsis:
    Exposes the native endianness or byte ordering of the system.

description:
    This package is for working with the native byte-ordering of
    the system.

category:             System
abi:                  fcc8d7641728e5d941b388c1a8c072ba
exposed:              True
exposed-modules:      System.ByteOrder
import-dirs:          /usr/lib/ghc-8.8.3/site-local/byteorder-1.0.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/byteorder-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/byteorder-1.0.4
hs-libraries:         HSbyteorder-1.0.4-KgJ9EHrGIhpJCFFHbRpXHY
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-byteorder/html/byteorder.haddock
haddock-html:         /usr/share/doc/haskell-byteorder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byteorder-1.0.4-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteorder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byteorder
version:              1.0.4
visibility:           public
id:                   byteorder-1.0.4-LXzUPfc8wT49Zewf3sQTva
key:                  byteorder-1.0.4-LXzUPfc8wT49Zewf3sQTva
license:              BSD-3-Clause
maintainer:           Antoine Latter <aslatter@gmail.com>
author:               Antoine Latter
homepage:             http://community.haskell.org/~aslatter/code/byteorder
synopsis:
    Exposes the native endianness or byte ordering of the system.

description:
    This package is for working with the native byte-ordering of
    the system.

category:             System
abi:                  c460752c5ca11af769ab262a0d073267
exposed:              True
exposed-modules:      System.ByteOrder
import-dirs:          /usr/lib/ghc-8.10.1/site-local/byteorder-1.0.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/byteorder-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/byteorder-1.0.4
hs-libraries:         HSbyteorder-1.0.4-LXzUPfc8wT49Zewf3sQTva
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-byteorder/html/byteorder.haddock
haddock-html:         /usr/share/doc/haskell-byteorder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
